]> granicus.if.org Git - neomutt/commitdiff
rename OPT_ variables
authorRichard Russon <rich@flatcap.org>
Sun, 8 Apr 2018 01:38:57 +0000 (02:38 +0100)
committerRichard Russon <rich@flatcap.org>
Sun, 8 Apr 2018 01:38:57 +0000 (02:38 +0100)
44 files changed:
attach.c
browser.c
color.c
commands.c
complete.c
compose.c
conn/sasl.c
conn/socket.c
conn/ssl.c
conn/ssl_gnutls.c
curs_lib.c
curs_main.c
handler.c
header.c
imap/util.c
init.c
keymap.c
main.c
menu.c
mutt/mbyte.c
mutt/mbyte.h
mutt_account.c
mutt_logging.c
mutt_window.c
mx.c
ncrypt/crypt.c
ncrypt/crypt_gpgme.c
ncrypt/pgp.c
ncrypt/pgpkey.c
options.h
pager.c
pattern.c
postpone.c
progress.c
recvattach.c
recvcmd.c
remailer.c
score.c
send.c
sendlib.c
signal.c
smtp.c
sort.c
status.c

index b984e814706c8104e351b8f57eaa49008d43c149..87084c39219ffc4b44711c88661fa6d5d21df609 100644 (file)
--- a/attach.c
+++ b/attach.c
@@ -579,14 +579,14 @@ int mutt_view_attachment(FILE *fp, struct Body *a, int flag, struct Header *hdr,
     else
     {
       /* Use built-in handler */
-      OPT_VIEW_ATTACH = true; /* disable the "use 'v' to view this part"
+      OptViewAttach = true; /* disable the "use 'v' to view this part"
                                    * message in case of error */
       if (mutt_decode_save_attachment(fp, a, pagerfile, MUTT_DISPLAY, 0))
       {
-        OPT_VIEW_ATTACH = false;
+        OptViewAttach = false;
         goto return_error;
       }
-      OPT_VIEW_ATTACH = false;
+      OptViewAttach = false;
     }
 
     if (a->description)
index 450e75a3dbd62b8fc2363b060b9c2af026e977cd..2e018524300198b2e35456f024f1f5933ff05dc1 100644 (file)
--- a/browser.c
+++ b/browser.c
@@ -244,7 +244,7 @@ static void browser_sort(struct BrowserState *state)
 #ifdef USE_NNTP
     case SORT_SIZE:
     case SORT_DATE:
-      if (OPT_NEWS)
+      if (OptNews)
         return;
 #endif
     default:
@@ -692,7 +692,7 @@ static void add_folder(struct Menu *m, struct BrowserState *state, const char *n
   (state->entry)[state->entrylen].imap = false;
 #endif
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
     (state->entry)[state->entrylen].nd = (struct NntpData *) data;
 #endif
   (state->entrylen)++;
@@ -717,7 +717,7 @@ static int examine_directory(struct Menu *menu, struct BrowserState *state,
                              char *d, const char *prefix)
 {
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
     struct NntpServer *nserv = CurrentNewsSrv;
 
@@ -852,7 +852,7 @@ static int examine_mailboxes(struct Menu *menu, struct BrowserState *state)
   struct stat s;
 
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
     struct NntpServer *nserv = CurrentNewsSrv;
 
@@ -943,7 +943,7 @@ static int examine_mailboxes(struct Menu *menu, struct BrowserState *state)
 static int select_file_search(struct Menu *menu, regex_t *re, int n)
 {
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
     return (regexec(re, ((struct FolderFile *) menu->data)[n].desc, 0, NULL, 0));
 #endif
   return (regexec(re, ((struct FolderFile *) menu->data)[n].name, 0, NULL, 0));
@@ -971,7 +971,7 @@ static void folder_entry(char *buf, size_t buflen, struct Menu *menu, int num)
   folder.num = num;
 
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
     mutt_expando_format(buf, buflen, 0, MuttIndexWindow->cols,
                         NONULL(GroupIndexFormat), group_index_format_str,
                         (unsigned long) &folder, MUTT_FORMAT_ARROWCURSOR);
@@ -1042,7 +1042,7 @@ static void init_menu(struct BrowserState *state, struct Menu *menu,
   menu->tagged = 0;
 
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
     if (buffy)
       snprintf(title, titlelen, _("Subscribed newsgroups"));
@@ -1170,7 +1170,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
   memset(&state, 0, sizeof(struct BrowserState));
 
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
     if (*f)
       mutt_str_strfcpy(prefix, f, sizeof(prefix));
@@ -1387,7 +1387,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
 
   menu->help = mutt_compile_help(helpstr, sizeof(helpstr), MENU_FOLDER,
 #ifdef USE_NNTP
-                                 OPT_NEWS ? FolderNewsHelp :
+                                 OptNews ? FolderNewsHelp :
 #endif
                                             FolderHelp);
   mutt_menu_push_current(menu);
@@ -1534,7 +1534,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
           }
         }
 
-        if (buffy || OPT_NEWS) /* USE_NNTP */
+        if (buffy || OptNews) /* USE_NNTP */
         {
           mutt_str_strfcpy(f, state.entry[menu->current].name, flen);
           mutt_expand_path(f, flen);
@@ -1697,7 +1697,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
       case OP_CHANGE_DIRECTORY:
 
 #ifdef USE_NNTP
-        if (OPT_NEWS)
+        if (OptNews)
           break;
 #endif
 
@@ -2031,7 +2031,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
 #ifdef USE_NNTP
       case OP_CATCHUP:
       case OP_UNCATCHUP:
-        if (OPT_NEWS)
+        if (OptNews)
         {
           struct FolderFile *ff = &state.entry[menu->current];
           int rc;
@@ -2060,7 +2060,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
         break;
 
       case OP_LOAD_ACTIVE:
-        if (OPT_NEWS)
+        if (OptNews)
         {
           struct NntpServer *nserv = CurrentNewsSrv;
 
@@ -2094,7 +2094,7 @@ void mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numfi
 #ifdef USE_NNTP
       case OP_SUBSCRIBE_PATTERN:
       case OP_UNSUBSCRIBE_PATTERN:
-        if (OPT_NEWS)
+        if (OptNews)
         {
           struct NntpServer *nserv = CurrentNewsSrv;
           regex_t rx;
diff --git a/color.c b/color.c
index 07789b91ab4aaa41113de1d6ef9e482a4193b43a..992913aab17bfb51ae69bea692b84c8254db8154 100644 (file)
--- a/color.c
+++ b/color.c
@@ -403,7 +403,7 @@ static int parse_color_name(const char *s, int *col, int *attr, int is_fg, struc
   {
     s += 5;
     *col = strtol(s, &eptr, 10);
-    if (!*s || *eptr || *col < 0 || (*col >= COLORS && !OPT_NO_CURSES && has_colors()))
+    if (!*s || *eptr || *col < 0 || (*col >= COLORS && !OptNoCurses && has_colors()))
     {
       snprintf(err->data, err->dsize, _("%s: color not supported by term"), s);
       return -1;
@@ -539,7 +539,7 @@ static int parse_uncolor(struct Buffer *buf, struct Buffer *s, unsigned long dat
   if (
 #ifdef HAVE_COLOR
       /* we're running without curses */
-      OPT_NO_CURSES || /* we're parsing an uncolor command, and have no colors */
+      OptNoCurses || /* we're parsing an uncolor command, and have no colors */
       (parse_uncolor && !has_colors())
       /* we're parsing an unmono command, and have colors */
       || (!parse_uncolor && has_colors())
@@ -578,7 +578,7 @@ static int parse_uncolor(struct Buffer *buf, struct Buffer *s, unsigned long dat
                    (object == MT_COLOR_INDEX_FLAGS) || (object == MT_COLOR_INDEX_SUBJECT) ||
                    (object == MT_COLOR_INDEX_TAG));
 
-  if (is_index && do_cache && !OPT_NO_CURSES)
+  if (is_index && do_cache && !OptNoCurses)
   {
     mutt_menu_set_redraw_full(MENU_MAIN);
     /* force re-caching of index colors */
@@ -885,7 +885,7 @@ static int parse_color(struct Buffer *buf, struct Buffer *s, struct Buffer *err,
 
 #ifdef HAVE_COLOR
 #ifdef HAVE_USE_DEFAULT_COLORS
-  if (!OPT_NO_CURSES &&
+  if (!OptNoCurses &&
       has_colors()
       /* delay use_default_colors() until needed, since it initializes things */
       && (fg == COLOR_DEFAULT || bg == COLOR_DEFAULT || object == MT_COLOR_TREE) &&
@@ -1000,7 +1000,7 @@ int mutt_parse_color(struct Buffer *buf, struct Buffer *s, unsigned long data,
 {
   bool dry_run = false;
 
-  if (OPT_NO_CURSES || !has_colors())
+  if (OptNoCurses || !has_colors())
     dry_run = true;
 
   return parse_color(buf, s, err, parse_color_pair, dry_run, true);
@@ -1014,10 +1014,10 @@ int mutt_parse_mono(struct Buffer *buf, struct Buffer *s, unsigned long data,
   bool dry_run = false;
 
 #ifdef HAVE_COLOR
-  if (OPT_NO_CURSES || has_colors())
+  if (OptNoCurses || has_colors())
     dry_run = true;
 #else
-  if (OPT_NO_CURSES)
+  if (OptNoCurses)
     dry_run = true;
 #endif
 
index 2c302dca33152dc555f7270ffb37c0ad59c506a8..53044b9ef1b0c92a46e44fc1a63917fedfe7e83b 100644 (file)
@@ -235,7 +235,7 @@ int mutt_display_message(struct Header *cur)
     if (r == -1)
       mutt_error(_("Error running \"%s\"!"), buf);
     unlink(tempfile);
-    if (!OPT_NO_CURSES)
+    if (!OptNoCurses)
       keypad(stdscr, true);
     if (r != -1)
       mutt_set_flag(Context, cur, MUTT_READ, 1);
@@ -409,11 +409,11 @@ static int pipe_message(struct Header *h, char *cmd, int decode, int print,
       return 1;
     }
 
-    OPT_KEEP_QUIET = true;
+    OptKeepQuiet = true;
     pipe_msg(h, fpout, decode, print);
     mutt_file_fclose(&fpout);
     rc = mutt_wait_filter(thepid);
-    OPT_KEEP_QUIET = false;
+    OptKeepQuiet = false;
   }
   else
   {
@@ -450,7 +450,7 @@ static int pipe_message(struct Header *h, char *cmd, int decode, int print,
           mutt_perror(_("Can't create filter process"));
           return 1;
         }
-        OPT_KEEP_QUIET = true;
+        OptKeepQuiet = true;
         pipe_msg(Context->hdrs[i], fpout, decode, print);
         /* add the message separator */
         if (sep)
@@ -458,7 +458,7 @@ static int pipe_message(struct Header *h, char *cmd, int decode, int print,
         mutt_file_fclose(&fpout);
         if (mutt_wait_filter(thepid) != 0)
           rc = 1;
-        OPT_KEEP_QUIET = false;
+        OptKeepQuiet = false;
       }
     }
     else
@@ -470,7 +470,7 @@ static int pipe_message(struct Header *h, char *cmd, int decode, int print,
         mutt_perror(_("Can't create filter process"));
         return 1;
       }
-      OPT_KEEP_QUIET = true;
+      OptKeepQuiet = true;
       for (int i = 0; i < Context->msgcount; i++)
       {
         if (!message_is_tagged(Context, i))
@@ -485,7 +485,7 @@ static int pipe_message(struct Header *h, char *cmd, int decode, int print,
       mutt_file_fclose(&fpout);
       if (mutt_wait_filter(thepid) != 0)
         rc = 1;
-      OPT_KEEP_QUIET = false;
+      OptKeepQuiet = false;
     }
   }
 
index c9988e4077fa25bd9af79acf235753d196682eb6..f5ed2724482dcb055e9abeecdbe42b8de8576003 100644 (file)
@@ -65,7 +65,7 @@ int mutt_complete(char *s, size_t slen)
   mutt_debug(2, "completing %s\n", s);
 
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
     struct NntpServer *nserv = CurrentNewsSrv;
     unsigned int n = 0;
index 25e6b1a664a240b2efb4eb4102bdd001bddae638..a213392d09979c78f81b06304cc2795c9dd0ad59 100644 (file)
--- a/handler.c
+++ b/handler.c
@@ -1876,7 +1876,7 @@ int mutt_body_handler(struct Body *b, struct State *s)
   }
   else if ((WithCrypto != 0) && b->type == TYPEAPPLICATION)
   {
-    if (OPT_DONT_HANDLE_PGP_KEYS && (mutt_str_strcasecmp("pgp-keys", b->subtype) == 0))
+    if (OptDontHandlePgpKeys && (mutt_str_strcasecmp("pgp-keys", b->subtype) == 0))
     {
       /* pass raw part through for key extraction */
       plaintext = true;
@@ -1889,14 +1889,14 @@ int mutt_body_handler(struct Body *b, struct State *s)
 
   /* only respect disposition == attachment if we're not
      displaying from the attachment menu (i.e. pager) */
-  if ((!HonorDisposition || (b->disposition != DISPATTACH || OPT_VIEW_ATTACH)) &&
+  if ((!HonorDisposition || (b->disposition != DISPATTACH || OptViewAttach)) &&
       (plaintext || handler))
   {
     rc = run_decode_and_handler(b, s, handler, plaintext);
   }
   /* print hint to use attachment menu for disposition == attachment
      if we're not already being called from there */
-  else if ((s->flags & MUTT_DISPLAY) || (b->disposition == DISPATTACH && !OPT_VIEW_ATTACH &&
+  else if ((s->flags & MUTT_DISPLAY) || (b->disposition == DISPATTACH && !OptViewAttach &&
                                          HonorDisposition && (plaintext || handler)))
   {
     state_mark_attach(s);
@@ -1904,7 +1904,7 @@ int mutt_body_handler(struct Body *b, struct State *s)
       fputs(_("[-- This is an attachment "), s->fpout);
     else
       state_printf(s, _("[-- %s/%s is unsupported "), TYPE(b), b->subtype);
-    if (!OPT_VIEW_ATTACH)
+    if (!OptViewAttach)
     {
       char keystroke[SHORT_STRING];
 
index 92065b6e6964fb9cd7ecdf3b728002e44dd08345..1b3f2c42adee16b2b96b00af423971830b58ab7f 100644 (file)
--- a/header.c
+++ b/header.c
@@ -126,7 +126,7 @@ void mutt_edit_headers(const char *editor, const char *body, struct Header *msg,
      we can simply compare strings as we don't generate References for
      multiple Message-Ids in IRT anyways */
 #ifdef USE_NNTP
-  if (!OPT_NEWS_SEND)
+  if (!OptNewsSend)
 #endif
     if (!STAILQ_EMPTY(&msg->env->in_reply_to) &&
         (STAILQ_EMPTY(&n->in_reply_to) ||
index d53d0f8f6b0c2d4068048c4aaf0e4d6aea519269..a7f8b576030ba6e13ae14af170e79eef4bc8818a 100644 (file)
@@ -936,7 +936,7 @@ int imap_wait_keepalive(pid_t pid)
   bool imap_passive = ImapPassive;
 
   ImapPassive = true;
-  OPT_KEEP_QUIET = true;
+  OptKeepQuiet = true;
 
   sigprocmask(SIG_SETMASK, NULL, &oldmask);
 
@@ -963,7 +963,7 @@ int imap_wait_keepalive(pid_t pid)
   sigaction(SIGALRM, &oldalrm, NULL);
   sigprocmask(SIG_SETMASK, &oldmask, NULL);
 
-  OPT_KEEP_QUIET = false;
+  OptKeepQuiet = false;
   if (!imap_passive)
     ImapPassive = false;
 
diff --git a/init.c b/init.c
index 57e7d50d08b0b8bf14be4f165baa6bab0862c2c3..1b3b545e107bc9a9696cac63e526bec7ac488ded 100644 (file)
--- a/init.c
+++ b/init.c
@@ -1725,7 +1725,7 @@ static int parse_alias(struct Buffer *buf, struct Buffer *s, unsigned long data,
     tmp->name = mutt_str_strdup(buf->data);
     /* give the main addressbook code a chance */
     if (CurrentMenu == MENU_ALIAS)
-      OPT_MENU_CALLER = true;
+      OptMenuCaller = true;
   }
   else
   {
@@ -1958,13 +1958,13 @@ static void restore_default(struct Option *p)
     mutt_menu_set_redraw(MENU_PAGER, REDRAW_FLOW);
   }
   if (p->flags & R_RESORT_SUB)
-    OPT_SORT_SUBTHREADS = true;
+    OptSortSubthreads = true;
   if (p->flags & R_RESORT)
-    OPT_NEED_RESORT = true;
+    OptNeedResort = true;
   if (p->flags & R_RESORT_INIT)
-    OPT_RESORT_INIT = true;
+    OptResortInit = true;
   if (p->flags & R_TREE)
-    OPT_REDRAW_TREE = true;
+    OptRedrawTree = true;
   if (p->flags & R_REFLOW)
     mutt_window_reflow();
 #ifdef USE_SIDEBAR
@@ -2221,10 +2221,10 @@ static int parse_set(struct Buffer *buf, struct Buffer *s, unsigned long data,
         for (idx = 0; MuttVars[idx].name; idx++)
           restore_default(&MuttVars[idx]);
         mutt_menu_set_current_redraw_full();
-        OPT_SORT_SUBTHREADS = true;
-        OPT_NEED_RESORT = true;
-        OPT_RESORT_INIT = true;
-        OPT_REDRAW_TREE = true;
+        OptSortSubthreads = true;
+        OptNeedResort = true;
+        OptResortInit = true;
+        OptRedrawTree = true;
         return 0;
       }
       else
@@ -2426,7 +2426,7 @@ static int parse_set(struct Buffer *buf, struct Buffer *s, unsigned long data,
         break;
       }
 
-      if (OPT_ATTACH_MSG &&
+      if (OptAttachMsg &&
           (mutt_str_strcmp(MuttVars[idx].name, "reply_regex") == 0))
       {
         snprintf(err->data, err->dsize, "Operation not permitted when in attach-message mode.");
@@ -2706,13 +2706,13 @@ static int parse_set(struct Buffer *buf, struct Buffer *s, unsigned long data,
         mutt_menu_set_redraw(MENU_PAGER, REDRAW_FLOW);
       }
       if (MuttVars[idx].flags & R_RESORT_SUB)
-        OPT_SORT_SUBTHREADS = true;
+        OptSortSubthreads = true;
       if (MuttVars[idx].flags & R_RESORT)
-        OPT_NEED_RESORT = true;
+        OptNeedResort = true;
       if (MuttVars[idx].flags & R_RESORT_INIT)
-        OPT_RESORT_INIT = true;
+        OptResortInit = true;
       if (MuttVars[idx].flags & R_TREE)
-        OPT_REDRAW_TREE = true;
+        OptRedrawTree = true;
       if (MuttVars[idx].flags & R_REFLOW)
         mutt_window_reflow();
 #ifdef USE_SIDEBAR
@@ -3797,7 +3797,7 @@ int mutt_init(int skip_sys_rc, struct ListHead *commands)
   if ((p = mutt_str_getenv("LC_ALL")) || (p = mutt_str_getenv("LANG")) ||
       (p = mutt_str_getenv("LC_CTYPE")))
   {
-    OPT_LOCALES = true;
+    OptLocales = true;
   }
 #endif
 
@@ -3936,7 +3936,7 @@ int mutt_init(int skip_sys_rc, struct ListHead *commands)
     mutt_str_replace(&Visual, env_ed);
   }
 
-  if (need_pause && !OPT_NO_CURSES)
+  if (need_pause && !OptNoCurses)
   {
     log_queue_flush(log_disp_terminal);
     if (mutt_any_key_to_continue(NULL) == 'q')
index d7c4de201e7d15062a89e7c0a113707d8a836865..cd2ed034d8381e0895e62bcc38f6a85b57e9d4b7 100644 (file)
--- a/keymap.c
+++ b/keymap.c
@@ -586,7 +586,7 @@ int km_dokey(int menu)
       if (map->op != OP_MACRO)
         return map->op;
 
-      if (OPT_IGNORE_MACRO_EVENTS)
+      if (OptIgnoreMacroEvents)
       {
         mutt_error(_("Macros are currently disabled."));
         return -1;
diff --git a/main.c b/main.c
index ddc6b8a5d044529edc141c6b88e47585d63db249..93b22341b1fea1dcdbe6e31844a381cf277cbb62 100644 (file)
--- a/main.c
+++ b/main.c
@@ -416,7 +416,7 @@ int main(int argc, char *argv[], char *envp[])
           break;
         default:
           usage();
-          OPT_NO_CURSES = true;
+          OptNoCurses = true;
           goto main_ok; // TEST03: neomutt -9
       }
     }
@@ -435,7 +435,7 @@ int main(int argc, char *argv[], char *envp[])
       print_version();
     else
       print_copyright();
-    OPT_NO_CURSES = true;
+    OptNoCurses = true;
     goto main_ok; // TEST04: neomutt -v
   }
 
@@ -500,7 +500,7 @@ int main(int argc, char *argv[], char *envp[])
   if (!isatty(0) || !STAILQ_EMPTY(&queries) || !STAILQ_EMPTY(&alias_queries) ||
       dump_variables || batch_mode)
   {
-    OPT_NO_CURSES = true;
+    OptNoCurses = true;
     sendflags = SENDBATCH;
     MuttLogger = log_disp_terminal;
     log_queue_flush(log_disp_terminal);
@@ -512,7 +512,7 @@ int main(int argc, char *argv[], char *envp[])
 
   /* This must come before mutt_init() because curses needs to be started
    * before calling the init_pair() function to set the color scheme.  */
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
   {
     int crc = start_curses();
     /* Now that curses is set up, we drop back to normal screen mode.
@@ -613,7 +613,7 @@ int main(int argc, char *argv[], char *envp[])
     goto main_curses; // TEST20: neomutt -A alias
   }
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
   {
     NORMAL_COLOR;
     clear();
@@ -623,7 +623,7 @@ int main(int argc, char *argv[], char *envp[])
   }
 
   /* Create the Folder directory if it doesn't exist. */
-  if (!OPT_NO_CURSES && Folder)
+  if (!OptNoCurses && Folder)
   {
     struct stat sb;
     char fpath[_POSIX_PATH_MAX];
@@ -657,7 +657,7 @@ int main(int argc, char *argv[], char *envp[])
 
   if (sendflags & SENDPOSTPONED)
   {
-    if (!OPT_NO_CURSES)
+    if (!OptNoCurses)
       mutt_flushinp();
     if (ci_send_message(SENDPOSTPONED, NULL, NULL, NULL, NULL) == 0)
       rc = 0;
@@ -677,7 +677,7 @@ int main(int argc, char *argv[], char *envp[])
     int rv = 0;
     char expanded_infile[_POSIX_PATH_MAX];
 
-    if (!OPT_NO_CURSES)
+    if (!OptNoCurses)
       mutt_flushinp();
 
     if (!msg)
@@ -966,7 +966,7 @@ int main(int argc, char *argv[], char *envp[])
 #ifdef USE_NNTP
       if (flags & MUTT_NEWS)
       {
-        OPT_NEWS = true;
+        OptNews = true;
         CurrentNewsSrv = nntp_select_server(NewsServer, false);
         if (!CurrentNewsSrv)
           goto main_curses; // TEST38: neomutt -G (unset news_server)
@@ -996,9 +996,9 @@ int main(int argc, char *argv[], char *envp[])
     }
 
 #ifdef USE_NNTP
-    if (OPT_NEWS)
+    if (OptNews)
     {
-      OPT_NEWS = false;
+      OptNews = false;
       nntp_expand_path(folder, sizeof(folder), &CurrentNewsSrv->conn->account);
     }
     else
diff --git a/menu.c b/menu.c
index 84b6e13e4abf08f6a1651c8e19dfef1ddd072d3d..e19a5970b53a8a7c71866eab9d7e6a9294a90d52 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -474,10 +474,10 @@ static void menu_redraw_prompt(struct Menu *menu)
 {
   if (menu->dialog)
   {
-    if (OPT_MSG_ERR)
+    if (OptMsgErr)
     {
       mutt_sleep(1);
-      OPT_MSG_ERR = false;
+      OptMsgErr = false;
     }
 
     if (ErrorBufMessage)
@@ -1088,9 +1088,9 @@ int mutt_menu_loop(struct Menu *menu)
 
   while (true)
   {
-    if (OPT_MENU_CALLER)
+    if (OptMenuCaller)
     {
-      OPT_MENU_CALLER = false;
+      OptMenuCaller = false;
       return OP_NULL;
     }
 
index 722f6fced11ed3e678f64bd104784e32f87be8c8..ea5237510971e7c7da9e42df6618a9a5b0765d0f 100644 (file)
@@ -40,7 +40,7 @@
 #include "memory.h"
 #include "string2.h"
 
-bool OPT_LOCALES; /**< (pseudo) set if user has valid locale definition */
+bool OptLocales; /**< (pseudo) set if user has valid locale definition */
 
 /**
  * mutt_mb_charlen - Count the bytes in a (multibyte) character
index c30c75da71422b6b65cf6d6149728853faf0d8e0..ce276f6c8e2983d4bbcc8fbdf58e8a81bb062676 100644 (file)
@@ -29,7 +29,7 @@
 #include <wchar.h>
 #include <wctype.h>
 
-extern bool OPT_LOCALES;
+extern bool OptLocales;
 
 #ifdef LOCALES_HACK
 #define IsPrint(c) (isprint((unsigned char) (c)) || ((unsigned char) (c) >= 0xa0))
@@ -37,8 +37,8 @@ extern bool OPT_LOCALES;
 #else
 #define IsPrint(c)                                                             \
   (isprint((unsigned char) (c)) ||                                             \
-   (OPT_LOCALES ? 0 : ((unsigned char) (c) >= 0xa0)))
-#define IsWPrint(wc) (iswprint(wc) || (OPT_LOCALES ? 0 : (wc >= 0xa0)))
+   (OptLocales ? 0 : ((unsigned char) (c) >= 0xa0)))
+#define IsWPrint(wc) (iswprint(wc) || (OptLocales ? 0 : (wc >= 0xa0)))
 #endif
 
 int    mutt_mb_charlen(const char *s, int *width);
index 6d37421d0fee42291427d183566b04ce9cb880b5..674b1a8af5f565a48218bd7c015a44c53f5ffe4a 100644 (file)
@@ -205,7 +205,7 @@ int mutt_account_getuser(struct Account *account)
   else if ((account->type == MUTT_ACCT_TYPE_NNTP) && NntpUser)
     mutt_str_strfcpy(account->user, NntpUser, sizeof(account->user));
 #endif
-  else if (OPT_NO_CURSES)
+  else if (OptNoCurses)
     return -1;
   /* prompt (defaults to unix username), copy into account->user */
   else
@@ -289,7 +289,7 @@ int mutt_account_getpass(struct Account *account)
   else if ((account->type == MUTT_ACCT_TYPE_NNTP) && NntpPass)
     mutt_str_strfcpy(account->pass, NntpPass, sizeof(account->pass));
 #endif
-  else if (OPT_NO_CURSES)
+  else if (OptNoCurses)
     return -1;
   else
   {
index c9c4ff976a3594f0217d8a42b0b32ca5995b7855..9b298d58a17ccfac82af043ca955b09c4e786763 100644 (file)
@@ -137,11 +137,11 @@ static const char *rotate_logs(const char *file, int count)
 void mutt_clear_error(void)
 {
   /* Make sure the error message has had time to be read */
-  if (OPT_MSG_ERR)
+  if (OptMsgErr)
     error_pause();
 
   ErrorBufMessage = false;
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_window_clearline(MuttMessageWindow, 0);
 }
 
@@ -194,14 +194,14 @@ int log_disp_curses(time_t stamp, const char *file, int line,
     return 0;
 
   /* Only pause if this is a message following an error */
-  if ((level > LL_ERROR) && OPT_MSG_ERR && !dupe)
+  if ((level > LL_ERROR) && OptMsgErr && !dupe)
     error_pause();
 
   mutt_simple_format(ErrorBuf, sizeof(ErrorBuf), 0, MuttMessageWindow->cols,
                      FMT_LEFT, 0, buf, sizeof(buf), 0);
   ErrorBufMessage = true;
 
-  if (!OPT_KEEP_QUIET)
+  if (!OptKeepQuiet)
   {
     if (level == LL_ERROR)
       BEEP();
@@ -214,13 +214,13 @@ int log_disp_curses(time_t stamp, const char *file, int line,
 
   if ((level <= LL_ERROR) && !dupe)
   {
-    OPT_MSG_ERR = true;
+    OptMsgErr = true;
     if (gettimeofday(&LastError, NULL) < 0)
       mutt_debug(1, "gettimeofday failed: %d\n", errno);
   }
   else
   {
-    OPT_MSG_ERR = false;
+    OptMsgErr = false;
     LastError.tv_sec = 0;
   }
 
index 4827e7bbd8ed1fceeda9f76794b65e0f59501371..f24cb25faa1e5e21cbc5998a9c31cd628b070e7c 100644 (file)
@@ -216,7 +216,7 @@ int mutt_window_mvprintw(struct MuttWindow *win, int row, int col, const char *f
  */
 void mutt_window_reflow(void)
 {
-  if (OPT_NO_CURSES)
+  if (OptNoCurses)
     return;
 
   mutt_debug(2, "entering\n");
diff --git a/mx.c b/mx.c
index 9773cb4b81e8e9e243edb230af4e8a5cc5ac9bde..0b34a2c2e90d8c20fbc373062b2548f759d6659a 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -472,7 +472,7 @@ struct Context *mx_open_mailbox(const char *path, int flags, struct Context *pct
    * mutt_refresh() will think we are in the middle of a macro.  so set a
    * flag to indicate that we should really refresh the screen.
    */
-  OPT_FORCE_REFRESH = true;
+  OptForceRefresh = true;
 
   if (!ctx->quiet)
     mutt_message(_("Reading %s..."), ctx->path);
@@ -485,8 +485,8 @@ struct Context *mx_open_mailbox(const char *path, int flags, struct Context *pct
     {
       /* avoid unnecessary work since the mailbox is completely unthreaded
          to begin with */
-      OPT_SORT_SUBTHREADS = false;
-      OPT_NEED_RESCORE = false;
+      OptSortSubthreads = false;
+      OptNeedRescore = false;
       mutt_sort_headers(ctx, 1);
     }
     if (!ctx->quiet)
@@ -501,7 +501,7 @@ struct Context *mx_open_mailbox(const char *path, int flags, struct Context *pct
       FREE(&ctx);
   }
 
-  OPT_FORCE_REFRESH = false;
+  OptForceRefresh = false;
   return ctx;
 }
 
index 9c45318dabd754840253ae8d62957343d73faf67..5fde82519caea1394168598c0f308768d995d407 100644 (file)
@@ -723,7 +723,7 @@ void crypt_extract_keys_from_messages(struct Header *h)
   }
 
   if (WithCrypto & APPLICATION_PGP)
-    OPT_DONT_HANDLE_PGP_KEYS = true;
+    OptDontHandlePgpKeys = true;
 
   if (!h)
   {
@@ -823,7 +823,7 @@ void crypt_extract_keys_from_messages(struct Header *h)
   mutt_file_unlink(tempfname);
 
   if (WithCrypto & APPLICATION_PGP)
-    OPT_DONT_HANDLE_PGP_KEYS = false;
+    OptDontHandlePgpKeys = false;
 }
 
 /**
@@ -849,7 +849,7 @@ int crypt_get_keys(struct Header *msg, char **keylist, int oppenc_mode)
     return 0;
 
   if (WithCrypto & APPLICATION_PGP)
-    OPT_PGP_CHECK_TRUST = true;
+    OptPgpCheckTrust = true;
 
   last = mutt_addr_append(&addrlist, msg->env->to, false);
   last = mutt_addr_append(last ? &last : &addrlist, msg->env->cc, false);
@@ -871,7 +871,7 @@ int crypt_get_keys(struct Header *msg, char **keylist, int oppenc_mode)
         mutt_addr_free(&addrlist);
         return -1;
       }
-      OPT_PGP_CHECK_TRUST = false;
+      OptPgpCheckTrust = false;
       if (PgpSelfEncrypt || (PgpEncryptSelf == MUTT_YES))
         self_encrypt = PgpDefaultKey;
     }
index bb4b9cc289fc65c46cbfd9944ce0ba191e5ad304..175251095fb6e160e953252f86abdac391d5d20d 100644 (file)
@@ -4250,7 +4250,7 @@ static struct CryptKeyInfo *crypt_select_key(struct CryptKeyInfo *keys,
       case OP_GENERIC_SELECT_ENTRY:
         /* FIXME make error reporting more verbose - this should be
              easy because gpgme provides more information */
-        if (OPT_PGP_CHECK_TRUST)
+        if (OptPgpCheckTrust)
         {
           if (!crypt_key_is_valid(key_table[menu->current]))
           {
@@ -4260,7 +4260,7 @@ static struct CryptKeyInfo *crypt_select_key(struct CryptKeyInfo *keys,
           }
         }
 
-        if (OPT_PGP_CHECK_TRUST && (!crypt_id_is_valid(key_table[menu->current]) ||
+        if (OptPgpCheckTrust && (!crypt_id_is_valid(key_table[menu->current]) ||
                                     !crypt_id_is_strong(key_table[menu->current])))
         {
           const char *warn_s = NULL;
@@ -4723,7 +4723,7 @@ struct Body *pgp_gpgme_make_key_attachment(char *tempf)
   char buf[LONG_STRING];
   struct stat sb;
 
-  OPT_PGP_CHECK_TRUST = false;
+  OptPgpCheckTrust = false;
 
   struct CryptKeyInfo *key = crypt_ask_for_key(_("Please enter the key ID: "), NULL, 0, APPLICATION_PGP, NULL);
   if (!key)
index b06cd3c60d619d4d4a359032897232f2e7af07f1..1d0f9e2f002e2b415b0c92da94edfcadd71f38b5 100644 (file)
@@ -794,7 +794,7 @@ void pgp_extract_keys_from_attachment_list(FILE *fp, int tag, struct Body *top)
   }
 
   mutt_endwin();
-  OPT_DONT_HANDLE_PGP_KEYS = true;
+  OptDontHandlePgpKeys = true;
 
   for (; top; top = top->next)
   {
@@ -805,7 +805,7 @@ void pgp_extract_keys_from_attachment_list(FILE *fp, int tag, struct Body *top)
       break;
   }
 
-  OPT_DONT_HANDLE_PGP_KEYS = false;
+  OptDontHandlePgpKeys = false;
 }
 
 static struct Body *pgp_decrypt_part(struct Body *a, struct State *s,
@@ -1774,7 +1774,7 @@ int pgp_send_menu(struct Header *msg)
     switch (choices[choice - 1])
     {
       case 'a': /* sign (a)s */
-        OPT_PGP_CHECK_TRUST = false;
+        OptPgpCheckTrust = false;
 
         p = pgp_ask_for_key(_("Sign as: "), NULL, 0, PGP_SECRING);
         if (p)
index 4d06698ef57b894ce4cf924907e2b8cd33b811d9..f27dee48122e8f4f21c0e5a089ef045a174f51b7 100644 (file)
@@ -615,7 +615,7 @@ static struct PgpKeyInfo *pgp_select_key(struct PgpKeyInfo *keys,
 
         /* XXX make error reporting more verbose */
 
-        if (OPT_PGP_CHECK_TRUST)
+        if (OptPgpCheckTrust)
         {
           if (!pgp_key_is_valid(KeyTable[menu->current]->parent))
           {
@@ -624,7 +624,7 @@ static struct PgpKeyInfo *pgp_select_key(struct PgpKeyInfo *keys,
           }
         }
 
-        if (OPT_PGP_CHECK_TRUST && (!pgp_id_is_valid(KeyTable[menu->current]) ||
+        if (OptPgpCheckTrust && (!pgp_id_is_valid(KeyTable[menu->current]) ||
                                     !pgp_id_is_strong(KeyTable[menu->current])))
         {
           char *str = "";
@@ -736,7 +736,7 @@ struct Body *pgp_make_key_attachment(char *tempf)
   FILE *devnull = NULL;
   struct stat sb;
   pid_t thepid;
-  OPT_PGP_CHECK_TRUST = false;
+  OptPgpCheckTrust = false;
 
   struct PgpKeyInfo *key = pgp_ask_for_key(_("Please enter the key ID: "), NULL, 0, PGP_PUBRING);
 
index dcd678d2146a5b080ef669b816f7f271da6c73de..892763b7e89c72005a31ee661ea35d2e23aa10ff 100644 (file)
--- a/options.h
+++ b/options.h
 
 /* pseudo options */
 
-WHERE bool OPT_ATTACH_MSG;           /**< (pseudo) used by attach-message */
-WHERE bool OPT_AUX_SORT;             /**< (pseudo) using auxiliary sort function */
-WHERE bool OPT_DONT_HANDLE_PGP_KEYS; /**< (pseudo) used to extract PGP keys */
-WHERE bool OPT_FORCE_REFRESH;        /**< (pseudo) refresh even during macros */
-WHERE bool OPT_HIDE_READ;            /**< (pseudo) whether or not hide read messages */
-WHERE bool OPT_IGNORE_MACRO_EVENTS;  /**< (pseudo) don't process macro/push/exec events while set */
-WHERE bool OPT_KEEP_QUIET;           /**< (pseudo) shut up the message and refresh functions while we are executing an external program.  */
-WHERE bool OPT_MENU_CALLER;          /**< (pseudo) tell menu to give caller a take */
-WHERE bool OPT_MSG_ERR;              /**< (pseudo) used by mutt_error/mutt_message */
-WHERE bool OPT_NEED_RESCORE;         /**< (pseudo) set when the `score' command is used */
-WHERE bool OPT_NEED_RESORT;          /**< (pseudo) used to force a re-sort */
+WHERE bool OptAttachMsg;           /**< (pseudo) used by attach-message */
+WHERE bool OptAuxSort;             /**< (pseudo) using auxiliary sort function */
+WHERE bool OptDontHandlePgpKeys; /**< (pseudo) used to extract PGP keys */
+WHERE bool OptForceRefresh;        /**< (pseudo) refresh even during macros */
+WHERE bool OptHideRead;            /**< (pseudo) whether or not hide read messages */
+WHERE bool OptIgnoreMacroEvents;  /**< (pseudo) don't process macro/push/exec events while set */
+WHERE bool OptKeepQuiet;           /**< (pseudo) shut up the message and refresh functions while we are executing an external program.  */
+WHERE bool OptMenuCaller;          /**< (pseudo) tell menu to give caller a take */
+WHERE bool OptMsgErr;              /**< (pseudo) used by mutt_error/mutt_message */
+WHERE bool OptNeedRescore;         /**< (pseudo) set when the `score' command is used */
+WHERE bool OptNeedResort;          /**< (pseudo) used to force a re-sort */
 #ifdef USE_NNTP
-WHERE bool OPT_NEWS;                 /**< (pseudo) used to change reader mode */
-WHERE bool OPT_NEWS_SEND;            /**< (pseudo) used to change behavior when posting */
+WHERE bool OptNews;                 /**< (pseudo) used to change reader mode */
+WHERE bool OptNewsSend;            /**< (pseudo) used to change behavior when posting */
 #endif
-WHERE bool OPT_NO_CURSES;            /**< (pseudo) when sending in batch mode */
-WHERE bool OPT_PGP_CHECK_TRUST;      /**< (pseudo) used by pgp_select_key () */
-WHERE bool OPT_REDRAW_TREE;          /**< (pseudo) redraw the thread tree */
-WHERE bool OPT_RESORT_INIT;          /**< (pseudo) used to force the next resort to be from scratch */
-WHERE bool OPT_SEARCH_INVALID;       /**< (pseudo) used to invalidate the search pat */
-WHERE bool OPT_SEARCH_REVERSE;       /**< (pseudo) used by ci_search_command */
-WHERE bool OPT_SIGNALS_BLOCKED;      /**< (pseudo) using by mutt_block_signals () */
-WHERE bool OPT_SORT_SUBTHREADS;      /**< (pseudo) used when $sort_aux changes */
-WHERE bool OPT_SYS_SIGNALS_BLOCKED;  /**< (pseudo) using by mutt_block_signals_system () */
-WHERE bool OPT_VIEW_ATTACH;          /**< (pseudo) signals that we are viewing attachments */
+WHERE bool OptNoCurses;            /**< (pseudo) when sending in batch mode */
+WHERE bool OptPgpCheckTrust;      /**< (pseudo) used by pgp_select_key () */
+WHERE bool OptRedrawTree;          /**< (pseudo) redraw the thread tree */
+WHERE bool OptResortInit;          /**< (pseudo) used to force the next resort to be from scratch */
+WHERE bool OptSearchInvalid;       /**< (pseudo) used to invalidate the search pat */
+WHERE bool OptSearchReverse;       /**< (pseudo) used by ci_search_command */
+WHERE bool OptSignalsBlocked;      /**< (pseudo) using by mutt_block_signals () */
+WHERE bool OptSortSubthreads;      /**< (pseudo) used when $sort_aux changes */
+WHERE bool OptSysSignalsBlocked;  /**< (pseudo) using by mutt_block_signals_system () */
+WHERE bool OptViewAttach;          /**< (pseudo) signals that we are viewing attachments */
 
 #define mutt_bit_set(v, n)    v[n / 8] |= (1 << (n % 8))
 #define mutt_bit_unset(v, n)  v[n / 8] &= ~(1 << (n % 8))
diff --git a/pager.c b/pager.c
index 0508c7f7ed9af2bbda10d95a8c6a3f6e1797cbd1..2d681891426320ed6d4751b151a87e9091e1c96a 100644 (file)
--- a/pager.c
+++ b/pager.c
@@ -95,7 +95,7 @@ static struct Header *OldHdr = NULL;
   }
 
 #define CHECK_ATTACH                                                           \
-  if (OPT_ATTACH_MSG)                                                          \
+  if (OptAttachMsg)                                                          \
   {                                                                            \
     mutt_flushinp();                                                           \
     mutt_error(_(Function_not_permitted_in_attach_message_mode));              \
@@ -2192,7 +2192,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, struct Pager *e
 
     bool do_new_mail = false;
 
-    if (Context && !OPT_ATTACH_MSG)
+    if (Context && !OptAttachMsg)
     {
       oldcount = Context ? Context->msgcount : 0;
       /* check for new mail */
@@ -2248,7 +2248,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, struct Pager *e
           }
 
           pager_menu->redraw = REDRAW_FULL;
-          OPT_SEARCH_INVALID = true;
+          OptSearchInvalid = true;
         }
       }
 
@@ -2616,7 +2616,7 @@ int mutt_pager(const char *banner, const char *fname, int flags, struct Pager *e
         CHECK_MODE(IsHeader(extra))
         if (mutt_select_sort((ch == OP_SORT_REVERSE)) == 0)
         {
-          OPT_NEED_RESORT = true;
+          OptNeedResort = true;
           ch = -1;
           rc = OP_DISPLAY_MESSAGE;
         }
@@ -2857,11 +2857,11 @@ int mutt_pager(const char *banner, const char *fname, int flags, struct Pager *e
 
         mutt_enter_command();
 
-        if (OPT_NEED_RESORT)
+        if (OptNeedResort)
         {
-          OPT_NEED_RESORT = false;
+          OptNeedResort = false;
           CHECK_MODE(IsHeader(extra));
-          OPT_NEED_RESORT = true;
+          OptNeedResort = true;
         }
 
         if (old_PagerIndexLines != PagerIndexLines)
index c8b986d4c23146ed39f8e24441f8f5c223d97df5..14a3890b8c9b1ac54dec88420889416a162cc9f7 100644 (file)
--- a/pattern.c
+++ b/pattern.c
@@ -2019,9 +2019,9 @@ int mutt_search_command(int cur, int op)
       return -1;
 
     if (op == OP_SEARCH || op == OP_SEARCH_NEXT)
-      OPT_SEARCH_REVERSE = false;
+      OptSearchReverse = false;
     else
-      OPT_SEARCH_REVERSE = true;
+      OptSearchReverse = true;
 
     /* compare the *expanded* version of the search pattern in case
        $simple_search has changed while we were searching */
@@ -2033,7 +2033,7 @@ int mutt_search_command(int cur, int op)
     {
       struct Buffer err;
       mutt_buffer_init(&err);
-      OPT_SEARCH_INVALID = true;
+      OptSearchInvalid = true;
       mutt_str_strfcpy(LastSearch, buf, sizeof(LastSearch));
       mutt_message(_("Compiling search pattern..."));
       mutt_pattern_free(&SearchPattern);
@@ -2052,7 +2052,7 @@ int mutt_search_command(int cur, int op)
     }
   }
 
-  if (OPT_SEARCH_INVALID)
+  if (OptSearchInvalid)
   {
     for (int i = 0; i < Context->msgcount; i++)
       Context->hdrs[i]->searched = false;
@@ -2060,10 +2060,10 @@ int mutt_search_command(int cur, int op)
     if (Context->magic == MUTT_IMAP && imap_search(Context, SearchPattern) < 0)
       return -1;
 #endif
-    OPT_SEARCH_INVALID = false;
+    OptSearchInvalid = false;
   }
 
-  int incr = (OPT_SEARCH_REVERSE) ? -1 : 1;
+  int incr = (OptSearchReverse) ? -1 : 1;
   if (op == OP_SEARCH_OPPOSITE)
     incr = -incr;
 
index 08473288c858fc3a75bde9c633659fa422e26dce..2395d5a3989f4ff79fbc0457d17872e1c4048389 100644 (file)
@@ -142,7 +142,7 @@ int mutt_num_postponed(int force)
   if (LastModify < st.st_mtime)
   {
 #ifdef USE_NNTP
-    int optnews = OPT_NEWS;
+    int optnews = OptNews;
 #endif
     LastModify = st.st_mtime;
 
@@ -150,7 +150,7 @@ int mutt_num_postponed(int force)
       return (PostCount = 0);
 #ifdef USE_NNTP
     if (optnews)
-      OPT_NEWS = false;
+      OptNews = false;
 #endif
     if (mx_open_mailbox(Postponed, MUTT_NOSORT | MUTT_QUIET, &ctx) == NULL)
       PostCount = 0;
@@ -159,7 +159,7 @@ int mutt_num_postponed(int force)
     mx_fastclose_mailbox(&ctx);
 #ifdef USE_NNTP
     if (optnews)
-      OPT_NEWS = true;
+      OptNews = true;
 #endif
   }
 
index ed4e1af3214c6310a11bdf5057de5c6da301a10c..cb8778f7160b04d2084e3f608722d5ae0125e13f 100644 (file)
@@ -109,7 +109,7 @@ void mutt_progress_init(struct Progress *progress, const char *msg,
 
   if (!progress)
     return;
-  if (OPT_NO_CURSES)
+  if (OptNoCurses)
     return;
 
   memset(progress, 0, sizeof(struct Progress));
@@ -158,7 +158,7 @@ void mutt_progress_update(struct Progress *progress, long pos, int percent)
   struct timeval tv = { 0, 0 };
   unsigned int now = 0;
 
-  if (OPT_NO_CURSES)
+  if (OptNoCurses)
     return;
 
   if (progress->inc == 0)
index 093cb901fc33c76b68323a7d65610769f31b7737..0545a103927129173280ad90570e56d5b2c50b8c 100644 (file)
@@ -1141,7 +1141,7 @@ static const char *Function_not_permitted =
     N_("Function not permitted in attach-message mode.");
 
 #define CHECK_ATTACH                                                           \
-  if (OPT_ATTACH_MSG)                                                          \
+  if (OptAttachMsg)                                                          \
   {                                                                            \
     mutt_flushinp();                                                           \
     mutt_error(_(Function_not_permitted));                                     \
index a394801dc9b94b29e5577405ba178c4394042a5e..5bfb2284614746e892b029a5242ff3361ef855b4 100644 (file)
--- a/recvcmd.c
+++ b/recvcmd.c
@@ -807,9 +807,9 @@ void mutt_attach_reply(FILE *fp, struct Header *hdr, struct AttachCtx *actx,
 
 #ifdef USE_NNTP
   if (flags & SENDNEWS)
-    OPT_NEWS_SEND = true;
+    OptNewsSend = true;
   else
-    OPT_NEWS_SEND = false;
+    OptNewsSend = false;
 #endif
 
   if (!check_all_msg(actx, cur, false))
index 7e9f61959bdb246caa2e44a78efbdba998b49b4c..f64d583c94805b9c544a2aa6c3648bf85c0e6247 100644 (file)
@@ -757,7 +757,7 @@ int mix_send_message(struct ListHead *chain, const char *tempfile)
   if (i != 0)
   {
     fprintf(stderr, _("Error sending message, child exited %d.\n"), i);
-    if (!OPT_NO_CURSES)
+    if (!OptNoCurses)
     {
       mutt_any_key_to_continue(NULL);
       mutt_error(_("Error sending message."));
diff --git a/score.c b/score.c
index de30dc5867fa35eaaf8b59afe436234bac67e85d..a30aabddb2071dea8aa61b4a06fdf6a5bde339c5 100644 (file)
--- a/score.c
+++ b/score.c
@@ -52,13 +52,13 @@ static struct Score *ScoreList = NULL;
 
 void mutt_check_rescore(struct Context *ctx)
 {
-  if (OPT_NEED_RESCORE && Score)
+  if (OptNeedRescore && Score)
   {
     if ((Sort & SORT_MASK) == SORT_SCORE || (SortAux & SORT_MASK) == SORT_SCORE)
     {
-      OPT_NEED_RESORT = true;
+      OptNeedResort = true;
       if ((Sort & SORT_MASK) == SORT_THREADS)
-        OPT_SORT_SUBTHREADS = true;
+        OptSortSubthreads = true;
     }
 
     /* must redraw the index since the user might have %N in it */
@@ -71,7 +71,7 @@ void mutt_check_rescore(struct Context *ctx)
       ctx->hdrs[i]->pair = 0;
     }
   }
-  OPT_NEED_RESCORE = false;
+  OptNeedRescore = false;
 }
 
 int mutt_parse_score(struct Buffer *buf, struct Buffer *s, unsigned long data,
@@ -136,7 +136,7 @@ int mutt_parse_score(struct Buffer *buf, struct Buffer *s, unsigned long data,
     mutt_str_strfcpy(err->data, _("Error: score: invalid number"), err->dsize);
     return -1;
   }
-  OPT_NEED_RESCORE = true;
+  OptNeedRescore = true;
   return 0;
 }
 
@@ -207,6 +207,6 @@ int mutt_parse_unscore(struct Buffer *buf, struct Buffer *s, unsigned long data,
       }
     }
   }
-  OPT_NEED_RESCORE = true;
+  OptNeedRescore = true;
   return 0;
 }
diff --git a/send.c b/send.c
index 0a560ecbe93439d72ecca4df98ece7e88a351fba..74949809a3682aa5e2137a3eddbc7f9a05ad29e6 100644 (file)
--- a/send.c
+++ b/send.c
@@ -215,7 +215,7 @@ static int edit_envelope(struct Envelope *en, int flags)
   char buf[HUGE_STRING];
 
 #ifdef USE_NNTP
-  if (OPT_NEWS_SEND)
+  if (OptNewsSend)
   {
     if (en->newsgroups)
       mutt_str_strfcpy(buf, en->newsgroups, sizeof(buf));
@@ -691,7 +691,7 @@ void mutt_add_to_reference_headers(struct Envelope *env, struct Envelope *curenv
   add_message_id(&env->in_reply_to, curenv);
 
 #ifdef USE_NNTP
-  if (OPT_NEWS_SEND && XCommentTo && curenv->from)
+  if (OptNewsSend && XCommentTo && curenv->from)
     env->x_comment_to = mutt_str_strdup(mutt_get_name(curenv->from));
 #endif
 }
@@ -933,7 +933,7 @@ void mutt_set_followup_to(struct Envelope *e)
   if (!FollowupTo)
     return;
 #ifdef USE_NNTP
-  if (OPT_NEWS_SEND)
+  if (OptNewsSend)
   {
     if (!e->followup_to && e->newsgroups && (strrchr(e->newsgroups, ',')))
       e->followup_to = mutt_str_strdup(e->newsgroups);
@@ -1107,7 +1107,7 @@ static int send_message(struct Header *msg)
 
 #ifdef USE_SMTP
 #ifdef USE_NNTP
-  if (!OPT_NEWS_SEND)
+  if (!OptNewsSend)
 #endif
     if (SmtpUrl)
       return mutt_smtp_send(msg->env->from, msg->env->to, msg->env->cc, msg->env->bcc,
@@ -1291,9 +1291,9 @@ int ci_send_message(int flags, struct Header *msg, char *tempfile,
 
 #ifdef USE_NNTP
   if (flags & SENDNEWS)
-    OPT_NEWS_SEND = true;
+    OptNewsSend = true;
   else
-    OPT_NEWS_SEND = false;
+    OptNewsSend = false;
 #endif
 
   if (!flags && !msg && Recall != MUTT_NO && mutt_num_postponed(1))
@@ -1339,12 +1339,12 @@ int ci_send_message(int flags, struct Header *msg, char *tempfile,
       if (msg->env->newsgroups)
       {
         flags |= SENDNEWS;
-        OPT_NEWS_SEND = true;
+        OptNewsSend = true;
       }
       else
       {
         flags &= ~SENDNEWS;
-        OPT_NEWS_SEND = false;
+        OptNewsSend = false;
       }
 #endif
     }
@@ -2002,7 +2002,7 @@ int ci_send_message(int flags, struct Header *msg, char *tempfile,
       free_clear_content = true;
   }
 
-  if (!OPT_NO_CURSES && !(flags & SENDMAILX))
+  if (!OptNoCurses && !(flags & SENDMAILX))
     mutt_message(_("Sending message..."));
 
   mutt_prepare_envelope(msg->env, 1);
@@ -2146,7 +2146,7 @@ int ci_send_message(int flags, struct Header *msg, char *tempfile,
       goto cleanup;
     }
   }
-  else if (!OPT_NO_CURSES && !(flags & SENDMAILX))
+  else if (!OptNoCurses && !(flags & SENDMAILX))
   {
     mutt_message(i != 0 ? _("Sending in background.") :
                           (flags & SENDNEWS) ? _("Article posted.") : /* USE_NNTP */
index 0e2b865c73ca031d0f40458de608e2b546d72d4f..a1e3cb89932e1192f82538eee2e11eab559ad812 100644 (file)
--- a/sendlib.c
+++ b/sendlib.c
@@ -2037,7 +2037,7 @@ int mutt_rfc822_write_header(FILE *fp, struct Envelope *env,
   }
   else if (mode > 0)
 #ifdef USE_NNTP
-    if (!OPT_NEWS_SEND)
+    if (!OptNewsSend)
 #endif
       fputs("To: \n", fp);
 
@@ -2048,7 +2048,7 @@ int mutt_rfc822_write_header(FILE *fp, struct Envelope *env,
   }
   else if (mode > 0)
 #ifdef USE_NNTP
-    if (!OPT_NEWS_SEND)
+    if (!OptNewsSend)
 #endif
       fputs("Cc: \n", fp);
 
@@ -2062,24 +2062,24 @@ int mutt_rfc822_write_header(FILE *fp, struct Envelope *env,
   }
   else if (mode > 0)
 #ifdef USE_NNTP
-    if (!OPT_NEWS_SEND)
+    if (!OptNewsSend)
 #endif
       fputs("Bcc: \n", fp);
 
 #ifdef USE_NNTP
   if (env->newsgroups)
     fprintf(fp, "Newsgroups: %s\n", env->newsgroups);
-  else if (mode == 1 && OPT_NEWS_SEND)
+  else if (mode == 1 && OptNewsSend)
     fputs("Newsgroups: \n", fp);
 
   if (env->followup_to)
     fprintf(fp, "Followup-To: %s\n", env->followup_to);
-  else if (mode == 1 && OPT_NEWS_SEND)
+  else if (mode == 1 && OptNewsSend)
     fputs("Followup-To: \n", fp);
 
   if (env->x_comment_to)
     fprintf(fp, "X-Comment-To: %s\n", env->x_comment_to);
-  else if (mode == 1 && OPT_NEWS_SEND && XCommentTo)
+  else if (mode == 1 && OptNewsSend && XCommentTo)
     fputs("X-Comment-To: \n", fp);
 #endif
 
@@ -2102,7 +2102,7 @@ int mutt_rfc822_write_header(FILE *fp, struct Envelope *env,
 
   if (env->mail_followup_to)
 #ifdef USE_NNTP
-    if (!OPT_NEWS_SEND)
+    if (!OptNewsSend)
 #endif
     {
       fputs("Mail-Followup-To: ", fp);
@@ -2464,7 +2464,7 @@ int mutt_invoke_sendmail(struct Address *from, struct Address *to, struct Addres
   int i;
 
 #ifdef USE_NNTP
-  if (OPT_NEWS_SEND)
+  if (OptNewsSend)
   {
     char cmd[LONG_STRING];
 
@@ -2518,7 +2518,7 @@ int mutt_invoke_sendmail(struct Address *from, struct Address *to, struct Addres
   }
 
 #ifdef USE_NNTP
-  if (!OPT_NEWS_SEND)
+  if (!OptNewsSend)
   {
 #endif
     size_t extra_argslen = 0;
@@ -2584,10 +2584,10 @@ int mutt_invoke_sendmail(struct Address *from, struct Address *to, struct Addres
    * and is set up to prompt using ncurses pinentry.  If we
    * mutt_endwin() it leaves other users staring at a blank screen.
    * So instead, just force a hard redraw on the next refresh. */
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_need_hard_redraw();
 
-  i = send_msg(path, args, msg, OPT_NO_CURSES ? NULL : &childout);
+  i = send_msg(path, args, msg, OptNoCurses ? NULL : &childout);
   if (i != (EX_OK & 0xff))
   {
     if (i != S_BKG)
@@ -2663,7 +2663,7 @@ void mutt_prepare_envelope(struct Envelope *env, int final)
 
   if (env->subject)
 #ifdef USE_NNTP
-    if (!OPT_NEWS_SEND || MimeSubject)
+    if (!OptNewsSend || MimeSubject)
 #endif
     {
       mutt_rfc2047_encode(&env->subject, NULL, sizeof("Subject:"), SendCharset);
@@ -2790,7 +2790,7 @@ int mutt_bounce_message(FILE *fp, struct Header *h, struct Address *to)
   mutt_addr_write(resent_from, sizeof(resent_from), from, false);
 
 #ifdef USE_NNTP
-  OPT_NEWS_SEND = false;
+  OptNewsSend = false;
 #endif
 
   /*
index 02a798193d5a8adbe8a28121e0eb04bdb6201b6f..c1419cafedfd560ff266cc4ea2be3e209b4113a9 100644 (file)
--- a/signal.c
+++ b/signal.c
@@ -173,7 +173,7 @@ void mutt_signal_init(void)
  */
 void mutt_block_signals(void)
 {
-  if (!OPT_SIGNALS_BLOCKED)
+  if (!OptSignalsBlocked)
   {
     sigemptyset(&Sigset);
     sigaddset(&Sigset, SIGTERM);
@@ -182,7 +182,7 @@ void mutt_block_signals(void)
     sigaddset(&Sigset, SIGINT);
     sigaddset(&Sigset, SIGWINCH);
     sigprocmask(SIG_BLOCK, &Sigset, 0);
-    OPT_SIGNALS_BLOCKED = true;
+    OptSignalsBlocked = true;
   }
 }
 
@@ -191,10 +191,10 @@ void mutt_block_signals(void)
  */
 void mutt_unblock_signals(void)
 {
-  if (OPT_SIGNALS_BLOCKED)
+  if (OptSignalsBlocked)
   {
     sigprocmask(SIG_UNBLOCK, &Sigset, 0);
-    OPT_SIGNALS_BLOCKED = false;
+    OptSignalsBlocked = false;
   }
 }
 
@@ -202,7 +202,7 @@ void mutt_block_signals_system(void)
 {
   struct sigaction sa;
 
-  if (!OPT_SYS_SIGNALS_BLOCKED)
+  if (!OptSysSignalsBlocked)
   {
     /* POSIX: ignore SIGINT and SIGQUIT & block SIGCHLD  before exec */
     sa.sa_handler = SIG_IGN;
@@ -214,13 +214,13 @@ void mutt_block_signals_system(void)
     sigemptyset(&SigsetSys);
     sigaddset(&SigsetSys, SIGCHLD);
     sigprocmask(SIG_BLOCK, &SigsetSys, 0);
-    OPT_SYS_SIGNALS_BLOCKED = true;
+    OptSysSignalsBlocked = true;
   }
 }
 
 void mutt_unblock_signals_system(int catch)
 {
-  if (OPT_SYS_SIGNALS_BLOCKED)
+  if (OptSysSignalsBlocked)
   {
     sigprocmask(SIG_UNBLOCK, &SigsetSys, NULL);
     if (catch)
@@ -239,7 +239,7 @@ void mutt_unblock_signals_system(int catch)
       sigaction(SIGINT, &sa, NULL);
     }
 
-    OPT_SYS_SIGNALS_BLOCKED = false;
+    OptSysSignalsBlocked = false;
   }
 }
 
diff --git a/smtp.c b/smtp.c
index 42a28a375373c73a1019b63137b0eb1837ff52cf..8d4b2e5a42d22a509d2d54c12f73acdb24e8e439 100644 (file)
--- a/smtp.c
+++ b/smtp.c
@@ -383,7 +383,7 @@ static int smtp_auth_sasl(struct Connection *conn, const char *mechlist)
     return SMTP_AUTH_UNAVAIL;
   }
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_message(_("Authenticating (%s)..."), mech);
 
   bufsize = ((len * 2) > LONG_STRING) ? (len * 2) : LONG_STRING;
diff --git a/sort.c b/sort.c
index c75c19878ba163fc94888c003648a49cd0a7c024..48c8e8ade10f8fe96f85c5ead1c7082d09a50c68 100644 (file)
--- a/sort.c
+++ b/sort.c
@@ -48,11 +48,11 @@ static int perform_auxsort(int retval, const void *a, const void *b)
 {
   /* If the items compared equal by the main sort
    * and we're not already doing an 'aux' sort...  */
-  if ((retval == 0) && AuxSort && !OPT_AUX_SORT)
+  if ((retval == 0) && AuxSort && !OptAuxSort)
   {
-    OPT_AUX_SORT = true;
+    OptAuxSort = true;
     retval = AuxSort(a, b);
-    OPT_AUX_SORT = false;
+    OptAuxSort = false;
   }
   /* If the items still match, use their index positions
    * to maintain a stable sort order */
@@ -303,7 +303,7 @@ void mutt_sort_headers(struct Context *ctx, int init)
   struct MuttThread *thread = NULL, *top = NULL;
   sort_t *sortfunc = NULL;
 
-  OPT_NEED_RESORT = false;
+  OptNeedResort = false;
 
   if (!ctx)
     return;
@@ -322,16 +322,16 @@ void mutt_sort_headers(struct Context *ctx, int init)
   if (!ctx->quiet)
     mutt_message(_("Sorting mailbox..."));
 
-  if (OPT_NEED_RESCORE && Score)
+  if (OptNeedRescore && Score)
   {
     for (int i = 0; i < ctx->msgcount; i++)
       mutt_score_message(ctx, ctx->hdrs[i], 1);
   }
-  OPT_NEED_RESCORE = false;
+  OptNeedRescore = false;
 
-  if (OPT_RESORT_INIT)
+  if (OptResortInit)
   {
-    OPT_RESORT_INIT = false;
+    OptResortInit = false;
     init = 1;
   }
 
@@ -343,14 +343,14 @@ void mutt_sort_headers(struct Context *ctx, int init)
     AuxSort = NULL;
     /* if $sort_aux changed after the mailbox is sorted, then all the
        subthreads need to be resorted */
-    if (OPT_SORT_SUBTHREADS)
+    if (OptSortSubthreads)
     {
       int i = Sort;
       Sort = SortAux;
       if (ctx->tree)
         ctx->tree = mutt_sort_subthreads(ctx->tree, 1);
       Sort = i;
-      OPT_SORT_SUBTHREADS = false;
+      OptSortSubthreads = false;
     }
     mutt_sort_threads(ctx, init);
   }
index 339c1f6bf655567f28f9f6eba31bcd7ed6530447..c5a0fa0e4560dc8a547e18ea9870b5d23eded9c9 100644 (file)
--- a/status.c
+++ b/status.c
@@ -260,7 +260,7 @@ static const char *status_format_str(char *buf, size_t buflen, size_t col, int c
 
       if (Context)
       {
-        i = OPT_ATTACH_MSG ?
+        i = OptAttachMsg ?
                 3 :
                 ((Context->readonly || Context->dontwrite) ?
                      2 :
--- a/compose.c
+++ b/compose.c
@@ -404,7 +404,7 @@ static void draw_envelope(struct Header *msg, char *fcc)
 {
   draw_envelope_addr(HDR_FROM, msg->env->from);
 #ifdef USE_NNTP
-  if (!OPT_NEWS_SEND)
+  if (!OptNewsSend)
   {
 #endif
     draw_envelope_addr(HDR_TO, msg->env->to);
@@ -789,7 +789,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
 #ifdef USE_NNTP
   int news = 0; /* is it a news article ? */
 
-  if (OPT_NEWS_SEND)
+  if (OptNewsSend)
     news++;
 #endif
 
@@ -819,7 +819,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
   while (loop)
   {
 #ifdef USE_NNTP
-    OPT_NEWS = false; /* for any case */
+    OptNews = false; /* for any case */
 #endif
     const int op = mutt_menu_loop(menu);
     switch (op)
@@ -1069,7 +1069,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
         fname[0] = 0;
 
 #ifdef USE_NNTP
-        OPT_NEWS = false;
+        OptNews = false;
         if (op == OP_COMPOSE_ATTACH_NEWS_MESSAGE)
         {
           CurrentNewsSrv = nntp_select_server(NewsServer, false);
@@ -1077,7 +1077,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
             break;
 
           prompt = _("Open newsgroup to attach message from");
-          OPT_NEWS = true;
+          OptNews = true;
         }
 #endif
 
@@ -1094,7 +1094,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
           break;
 
 #ifdef USE_NNTP
-        if (OPT_NEWS)
+        if (OptNews)
           nntp_expand_path(fname, sizeof(fname), &CurrentNewsSrv->conn->account);
         else
 #endif
@@ -1106,7 +1106,7 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
           if (!mx_is_pop(fname))
 #endif
 #ifdef USE_NNTP
-            if (!mx_is_nntp(fname) && !OPT_NEWS)
+            if (!mx_is_nntp(fname) && !OptNews)
 #endif
               /* check to make sure the file exists and is readable */
               if (access(fname, R_OK) == -1)
@@ -1137,10 +1137,10 @@ int mutt_compose_menu(struct Header *msg, char *fcc, size_t fcclen,
         old_sort_aux = SortAux;
 
         Context = ctx;
-        OPT_ATTACH_MSG = true;
+        OptAttachMsg = true;
         mutt_message(_("Tag the messages you want to attach!"));
         close = mutt_index_menu();
-        OPT_ATTACH_MSG = false;
+        OptAttachMsg = false;
 
         if (!Context)
         {
index 083c795d0e0dfe92321bb2f080864f5b6c6b6bc0..5135b3aa57578b4435a7d4ad4b8e8155d3203f74 100644 (file)
@@ -642,7 +642,7 @@ int mutt_sasl_interact(sasl_interact_t *interaction)
 
     snprintf(prompt, sizeof(prompt), "%s: ", interaction->prompt);
     resp[0] = '\0';
-    if (OPT_NO_CURSES || mutt_get_field(prompt, resp, sizeof(resp), 0))
+    if (OptNoCurses || mutt_get_field(prompt, resp, sizeof(resp), 0))
       return SASL_FAIL;
 
     interaction->len = mutt_str_strlen(resp) + 1;
index bb368785cfb017d674c8bb595fea79310ca0a592..05680ae8dc9fc3d2584e7c82088f125c1defec54 100644 (file)
@@ -481,7 +481,7 @@ int raw_socket_open(struct Connection *conn)
   host_idna = conn->account.host;
 #endif
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_message(_("Looking up %s..."), conn->account.host);
 
   rc = getaddrinfo(host_idna, port, &hints, &res);
@@ -496,7 +496,7 @@ int raw_socket_open(struct Connection *conn)
     return -1;
   }
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_message(_("Connecting to %s..."), conn->account.host);
 
   rc = -1;
@@ -539,7 +539,7 @@ int raw_socket_open(struct Connection *conn)
   host_idna = conn->account.host;
 #endif
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_message(_("Looking up %s..."), conn->account.host);
 
   he = gethostbyname(host_idna);
@@ -555,7 +555,7 @@ int raw_socket_open(struct Connection *conn)
     return -1;
   }
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
     mutt_message(_("Connecting to %s..."), conn->account.host);
 
   rc = -1;
index 9318081487755991da9c329aab57362d58f54f81..25e6527a1da7dc43ef818e6d03fe98c52102102c 100644 (file)
@@ -1043,7 +1043,7 @@ static int interactive_check_cert(X509 *cert, int idx, size_t len, SSL *ssl, int
   menu->help = helpstr;
 
   done = 0;
-  OPT_IGNORE_MACRO_EVENTS = true;
+  OptIgnoreMacroEvents = true;
   while (!done)
   {
     switch (mutt_menu_loop(menu))
@@ -1087,7 +1087,7 @@ static int interactive_check_cert(X509 *cert, int idx, size_t len, SSL *ssl, int
         break;
     }
   }
-  OPT_IGNORE_MACRO_EVENTS = false;
+  OptIgnoreMacroEvents = false;
   mutt_menu_pop_current(menu);
   mutt_menu_destroy(&menu);
   mutt_debug(2, "done=%d\n", done);
index ff8096b1149990558a1113be6cca041ae7365dd7..cc6c284ca356807f69a667db91ca30aa23151ebd 100644 (file)
@@ -795,7 +795,7 @@ static int tls_check_one_certificate(const gnutls_datum_t *certdata,
   menu->help = helpstr;
 
   done = 0;
-  OPT_IGNORE_MACRO_EVENTS = true;
+  OptIgnoreMacroEvents = true;
   while (!done)
   {
     switch (mutt_menu_loop(menu))
@@ -846,7 +846,7 @@ static int tls_check_one_certificate(const gnutls_datum_t *certdata,
         break;
     }
   }
-  OPT_IGNORE_MACRO_EVENTS = false;
+  OptIgnoreMacroEvents = false;
   mutt_menu_pop_current(menu);
   mutt_menu_destroy(&menu);
   gnutls_x509_crt_deinit(cert);
@@ -1198,7 +1198,7 @@ static int tls_negotiate(struct Connection *conn)
 
   tls_get_client_cert(conn);
 
-  if (!OPT_NO_CURSES)
+  if (!OptNoCurses)
   {
     mutt_message(_("SSL/TLS connection using %s (%s/%s/%s)"),
                  gnutls_protocol_get_name(gnutls_protocol_get_version(data->state)),
index d49a8ea0ac524ef5333884d03444be2f15450952..3e45ebd62b0a88e9b913039c42aa77ecf85a49d2 100644 (file)
  */
 
 /* These are used for macros and exec/push commands.
* They can be temporarily ignored by setting OPT_IGNORE_MACRO_EVENTS
  */
 static size_t MacroBufferCount = 0;
 static size_t MacroBufferLen = 0;
 static struct Event *MacroEvents;
 
 /* These are used in all other "normal" situations, and are not
* ignored when setting OPT_IGNORE_MACRO_EVENTS
  */
 static size_t UngetCount = 0;
 static size_t UngetLen = 0;
@@ -80,11 +80,11 @@ static struct Event *UngetKeyEvents;
 void mutt_refresh(void)
 {
   /* don't refresh when we are waiting for a child. */
-  if (OPT_KEEP_QUIET)
+  if (OptKeepQuiet)
     return;
 
   /* don't refresh in the middle of macros unless necessary */
-  if (MacroBufferCount && !OPT_FORCE_REFRESH && !OPT_IGNORE_MACRO_EVENTS)
+  if (MacroBufferCount && !OptForceRefresh && !OptIgnoreMacroEvents)
     return;
 
   /* else */
@@ -115,7 +115,7 @@ struct Event mutt_getch(void)
   if (UngetCount)
     return UngetKeyEvents[--UngetCount];
 
-  if (!OPT_IGNORE_MACRO_EVENTS && MacroBufferCount)
+  if (!OptIgnoreMacroEvents && MacroBufferCount)
     return MacroEvents[--MacroBufferCount];
 
   SigInt = 0;
@@ -195,9 +195,9 @@ int mutt_get_field_unbuffered(char *msg, char *buf, size_t buflen, int flags)
 {
   int rc;
 
-  OPT_IGNORE_MACRO_EVENTS = true;
+  OptIgnoreMacroEvents = true;
   rc = mutt_get_field(msg, buf, buflen, flags);
-  OPT_IGNORE_MACRO_EVENTS = false;
+  OptIgnoreMacroEvents = false;
 
   return rc;
 }
@@ -374,10 +374,10 @@ void mutt_query_exit(void)
 
 void mutt_show_error(void)
 {
-  if (OPT_KEEP_QUIET || !ErrorBufMessage)
+  if (OptKeepQuiet || !ErrorBufMessage)
     return;
 
-  SETCOLOR(OPT_MSG_ERR ? MT_COLOR_ERROR : MT_COLOR_MESSAGE);
+  SETCOLOR(OptMsgErr ? MT_COLOR_ERROR : MT_COLOR_MESSAGE);
   mutt_window_mvaddstr(MuttMessageWindow, 0, 0, ErrorBuf);
   NORMAL_COLOR;
   mutt_window_clrtoeol(MuttMessageWindow);
@@ -385,7 +385,7 @@ void mutt_show_error(void)
 
 void mutt_endwin(void)
 {
-  if (OPT_NO_CURSES)
+  if (OptNoCurses)
     return;
 
   int e = errno;
index 4f1af9d09ba5c0c014d2f9d2d32af67256bd16c1..0799d64f163aae338ea5bc897591655286422711 100644 (file)
@@ -127,7 +127,7 @@ static const char *NoVisible = N_("No visible messages.");
   }
 
 #define CHECK_ATTACH                                                           \
-  if (OPT_ATTACH_MSG)                                                          \
+  if (OptAttachMsg)                                                          \
   {                                                                            \
     mutt_flushinp();                                                           \
     mutt_error(_(Function_not_permitted_in_attach_message_mode));              \
@@ -426,9 +426,9 @@ static int main_change_folder(struct Menu *menu, int op, char *buf,
                               size_t buflen, int *oldcount, int *index_hint)
 {
 #ifdef USE_NNTP
-  if (OPT_NEWS)
+  if (OptNews)
   {
-    OPT_NEWS = false;
+    OptNews = false;
     nntp_expand_path(buf, buflen, &CurrentNewsSrv->conn->account);
   }
   else
@@ -463,7 +463,7 @@ static int main_change_folder(struct Menu *menu, int op, char *buf,
         update_index(menu, Context, check, *oldcount, *index_hint);
 
       FREE(&new_last_folder);
-      OPT_SEARCH_INVALID = true;
+      OptSearchInvalid = true;
       menu->redraw |= REDRAW_INDEX | REDRAW_STATUS;
       return 0;
     }
@@ -504,7 +504,7 @@ static int main_change_folder(struct Menu *menu, int op, char *buf,
   mutt_clear_error();
   mutt_buffy_check(true); /* force the buffy check after we have changed the folder */
   menu->redraw = REDRAW_FULL;
-  OPT_SEARCH_INVALID = true;
+  OptSearchInvalid = true;
 
   return 0;
 }
@@ -836,7 +836,7 @@ int mutt_index_menu(void)
   int index_hint;  /* used to restore cursor position */
   bool do_buffy_notify = true;
   int close = 0; /* did we OP_QUIT or OP_EXIT out of this menu? */
-  int attach_msg = OPT_ATTACH_MSG;
+  int attach_msg = OptAttachMsg;
 
   struct Menu *menu = mutt_menu_new(MENU_MAIN);
   menu->make_entry = index_make_entry;
@@ -872,17 +872,17 @@ int mutt_index_menu(void)
      * any 'op' below could do mutt_enter_command(), either here or
      * from any new menu launched, and change $sort/$sort_aux
      */
-    if (OPT_NEED_RESORT && Context && Context->msgcount && menu->current >= 0)
+    if (OptNeedResort && Context && Context->msgcount && menu->current >= 0)
       resort_index(menu);
 
     menu->max = Context ? Context->vcount : 0;
     oldcount = Context ? Context->msgcount : 0;
 
-    if (OPT_REDRAW_TREE && Context && Context->msgcount && (Sort & SORT_MASK) == SORT_THREADS)
+    if (OptRedrawTree && Context && Context->msgcount && (Sort & SORT_MASK) == SORT_THREADS)
     {
       mutt_draw_tree(Context);
       menu->redraw |= REDRAW_STATUS;
-      OPT_REDRAW_TREE = false;
+      OptRedrawTree = false;
     }
 
     if (Context)
@@ -911,7 +911,7 @@ int mutt_index_menu(void)
           menu->redraw = REDRAW_FULL;
         }
 
-        OPT_SEARCH_INVALID = true;
+        OptSearchInvalid = true;
       }
       else if (check == MUTT_NEW_MAIL || check == MUTT_REOPENED || check == MUTT_FLAGS)
       {
@@ -953,7 +953,7 @@ int mutt_index_menu(void)
         menu->redraw = REDRAW_FULL;
         menu->max = Context->vcount;
 
-        OPT_SEARCH_INVALID = true;
+        OptSearchInvalid = true;
       }
     }
 
@@ -1090,7 +1090,7 @@ int mutt_index_menu(void)
     }
 
 #ifdef USE_NNTP
-    OPT_NEWS = false; /* for any case */
+    OptNews = false; /* for any case */
 #endif
 
 #ifdef USE_NOTMUCH
@@ -1463,14 +1463,14 @@ int mutt_index_menu(void)
           {
             snprintf(buf2, sizeof(buf2), "!~R!~D~s%s",
                      Context->pattern ? Context->pattern : ".*");
-            OPT_HIDE_READ = true;
+            OptHideRead = true;
           }
           else
           {
             mutt_str_strfcpy(buf2, Context->pattern + 8, sizeof(buf2));
             if (!*buf2 || (strncmp(buf2, ".*", 2) == 0))
               snprintf(buf2, sizeof(buf2), "~A");
-            OPT_HIDE_READ = false;
+            OptHideRead = false;
           }
           FREE(&Context->pattern);
           Context->pattern = mutt_str_strdup(buf2);
@@ -1531,7 +1531,7 @@ int mutt_index_menu(void)
               update_index(menu, Context, check, oldcount, index_hint);
 
             menu->redraw = REDRAW_FULL; /* new mail arrived? */
-            OPT_SEARCH_INVALID = true;
+            OptSearchInvalid = true;
           }
         }
         break;
@@ -1564,7 +1564,7 @@ int mutt_index_menu(void)
           if (Context && Context->msgcount)
           {
             resort_index(menu);
-            OPT_SEARCH_INVALID = true;
+            OptSearchInvalid = true;
           }
           if (menu->menu == MENU_PAGER)
           {
@@ -1661,7 +1661,7 @@ int mutt_index_menu(void)
         {
           if (mx_close_mailbox(Context, &index_hint) != 0)
           {
-            OPT_SEARCH_INVALID = true;
+            OptSearchInvalid = true;
             menu->redraw = REDRAW_FULL;
             break;
           }
@@ -1669,7 +1669,7 @@ int mutt_index_menu(void)
         }
         imap_logout_all();
         mutt_message(_("Logged out of IMAP servers."));
-        OPT_SEARCH_INVALID = true;
+        OptSearchInvalid = true;
         menu->redraw = REDRAW_FULL;
         break;
 #endif
@@ -1715,7 +1715,7 @@ int mutt_index_menu(void)
                 }
               }
             }
-            OPT_SEARCH_INVALID = true;
+            OptSearchInvalid = true;
           }
           else if (check == MUTT_NEW_MAIL || check == MUTT_REOPENED)
             update_index(menu, Context, check, oc, index_hint);
@@ -1976,7 +1976,7 @@ int mutt_index_menu(void)
 #ifdef USE_NNTP
       case OP_MAIN_CHANGE_GROUP:
       case OP_MAIN_CHANGE_GROUP_READONLY:
-        OPT_NEWS = false;
+        OptNews = false;
 #endif
         if (attach_msg || ReadOnly ||
 #ifdef USE_NNTP
@@ -2046,7 +2046,7 @@ int mutt_index_menu(void)
 #ifdef USE_NNTP
           if (op == OP_MAIN_CHANGE_GROUP || op == OP_MAIN_CHANGE_GROUP_READONLY)
           {
-            OPT_NEWS = true;
+            OptNews = true;
             CurrentNewsSrv = nntp_select_server(NewsServer, false);
             if (!CurrentNewsSrv)
               break;
@@ -2108,7 +2108,7 @@ int mutt_index_menu(void)
         if (op == OP_DISPLAY_HEADERS)
           Weed = !Weed;
 
-        OPT_NEED_RESORT = false;
+        OptNeedResort = false;
 
         if ((Sort & SORT_MASK) == SORT_THREADS && CURHDR->collapsed)
         {
@@ -2132,7 +2132,7 @@ int mutt_index_menu(void)
         op = mutt_display_message(CURHDR);
         if (op < 0)
         {
-          OPT_NEED_RESORT = false;
+          OptNeedResort = false;
           break;
         }
 
@@ -1198,7 +1198,7 @@ static int tls_negotiate(struct Connection *conn)
 
 /* These are used for macros and exec/push commands.
- * They can be temporarily ignored by setting OPT_IGNORE_MACRO_EVENTS
+ * They can be temporarily ignored by setting OptIgnoreMacroEvents
  */
 static size_t MacroBufferCount = 0;
@@ -1198,7 +1198,7 @@ static int tls_negotiate(struct Connection *conn)
 
 /* These are used in all other "normal" situations, and are not
- * ignored when setting OPT_IGNORE_MACRO_EVENTS
+ * ignored when setting OptIgnoreMacroEvents
  */
 static size_t UngetCount = 0;
index ad4b877097684f4892bc62dafc5a58b5e58febf1..78e3c696666d60db553429a01b0da19ab1d1f9fb 100644 (file)